@@ -146,7 +146,9 @@ get_trip_geometry <- function(gtfs_sf_obj, trip_ids) {
   }
 
   trips = gtfs_sf_obj$trips %>% filter(trip_id %in% trip_ids)
-  trips_shapes = dplyr::inner_join(gtfs_sf_obj$shapes, trips, by = "shape_id")
+  trips_shapes = suppress_matches_multiple_warning(
+    dplyr::inner_join(gtfs_sf_obj$shapes, trips, by = "shape_id")
+  )
   return(trips_shapes)
 }
 
