@@ -1,18 +1,18 @@
 #' Returns TRUE if the given gtfs_obj contains the table. Used to check for
-#' tidytransit's calculated tables in sublist
-#' @param gtfs_obj gtfs object
-#' @param table_name name as string of the table to look for
+#' tidytransit's calculated tables in sublist (\code{gtfs_obj$.})
+#' @param gtfs_obj gtfs feed (tidygtfs object)
+#' @param table_name name of the table to look for, as string
 feed_contains <- function(gtfs_obj, table_name) {
   exists(table_name, where = gtfs_obj) ||
     (exists(".", where = gtfs_obj) && exists(table_name, where = gtfs_obj$.))
 }
 
-#' Convert empty strings ("") to NA values in gtfs tables
-#' 
-#' @param gtfs_obj tidygtfs object
+#' Convert empty strings ("") to NA values in all gtfs tables
 #' 
+#' @param gtfs_obj gtfs feed (tidygtfs object)
+#'  
 #' @return a gtfs_obj where all empty strings in tables have been replaced with NA
-#' 
+#' @seealso [na_to_empty_strings()]
 #' @export
 empty_strings_to_na = function(gtfs_obj) {
   tbl_names = names(gtfs_obj)
@@ -27,7 +27,10 @@ empty_strings_to_na = function(gtfs_obj) {
 
 #' Convert NA values to empty strings ("")
 #'  
-#' @param gtfs_obj tidygtfs object
+#' @param gtfs_obj gtfs feed (tidygtfs object)
+#' @return a gtfs_obj where all NA strings in tables have been replaced with ""
+#' @seealso [empty_strings_to_na()]
+#' @export
 na_to_empty_strings = function(gtfs_obj) {
   lapply(gtfs_obj, function(df) {
     if(inherits(df, "data.frame")) {
@@ -45,3 +48,16 @@ na_to_empty_strings = function(gtfs_obj) {
     df
   })
 }
+
+# TODO: Remove after dplyr 1.1.0 is released and use `multiple = "all"` instead
+suppress_matches_multiple_warning <- function(expr) {
+  handler_matches_multiple <- function(cnd) {
+    if (inherits(cnd, "dplyr_warning_join_matches_multiple")) {
+      restart <- findRestart("muffleWarning")
+      if (!is.null(restart)) {
+        invokeRestart(restart)
+      }
+    }
+  }
+  withCallingHandlers(expr, warning = handler_matches_multiple)
+}
